@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Xdebug                                                               |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2002-2012 Derick Rethans                               |
+   | Copyright (c) 2002-2013 Derick Rethans                               |
    +----------------------------------------------------------------------+
    | This source file is subject to version 1.0 of the Xdebug license,    |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -65,11 +65,19 @@
 zend_op_array* (*old_compile_file)(zend_file_handle* file_handle, int type TSRMLS_DC);
 zend_op_array* xdebug_compile_file(zend_file_handle*, int TSRMLS_DC);
 
+#if PHP_VERSION_ID < 50500
 void (*xdebug_old_execute)(zend_op_array *op_array TSRMLS_DC);
 void xdebug_execute(zend_op_array *op_array TSRMLS_DC);
 
 void (*xdebug_old_execute_internal)(zend_execute_data *current_execute_data, int return_value_used TSRMLS_DC);
 void xdebug_execute_internal(zend_execute_data *current_execute_data, int return_value_used TSRMLS_DC);
+#else
+void (*xdebug_old_execute_ex)(zend_execute_data *execute_data TSRMLS_DC);
+void xdebug_execute_ex(zend_execute_data *execute_data TSRMLS_DC);
+
+void (*xdebug_old_execute_internal)(zend_execute_data *current_execute_data, struct _zend_fcall_info *fci, int return_value_used TSRMLS_DC);
+void xdebug_execute_internal(zend_execute_data *current_execute_data, struct _zend_fcall_info *fci, int return_value_used TSRMLS_DC);
+#endif
 
 /* error callback replacement functions */
 void (*xdebug_old_error_cb)(int type, const char *error_filename, const uint error_lineno, const char *format, va_list args);
@@ -483,7 +491,7 @@ static int xdebug_include_or_eval_handler(ZEND_OPCODE_HANDLER_ARGS)
 		zval tmp_inc_filename;
 		int  is_var;
 
-		inc_filename = xdebug_get_zval(execute_data, opline->XDEBUG_TYPE(op1), &opline->op1, execute_data->Ts, &is_var);
+		inc_filename = xdebug_get_zval(execute_data, opline->XDEBUG_TYPE(op1), &opline->op1, &is_var);
 		
 		/* If there is no inc_filename, we're just bailing out instead */
 		if (!inc_filename) {
@@ -561,8 +569,13 @@ PHP_MINIT_FUNCTION(xdebug)
 	old_compile_file = zend_compile_file;
 	zend_compile_file = xdebug_compile_file;
 
+#if PHP_VERSION_ID < 50500
 	xdebug_old_execute = zend_execute;
 	zend_execute = xdebug_execute;
+#else
+	xdebug_old_execute_ex = zend_execute_ex;
+	zend_execute_ex = xdebug_execute_ex;
+#endif
 
 	xdebug_old_execute_internal = zend_execute_internal;
 	zend_execute_internal = xdebug_execute_internal;
@@ -629,6 +642,10 @@ PHP_MINIT_FUNCTION(xdebug)
 		XDEBUG_SET_OPCODE_OVERRIDE_COMMON(ZEND_QM_ASSIGN);
 #if (PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION >= 3) || PHP_MAJOR_VERSION >= 6
 		XDEBUG_SET_OPCODE_OVERRIDE_COMMON(ZEND_DECLARE_LAMBDA_FUNCTION);
+#endif
+#if (PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION >= 4)
+		XDEBUG_SET_OPCODE_OVERRIDE_COMMON(ZEND_ADD_TRAIT);
+		XDEBUG_SET_OPCODE_OVERRIDE_COMMON(ZEND_BIND_TRAITS);
 #endif
 	}
 
@@ -696,7 +713,11 @@ PHP_MSHUTDOWN_FUNCTION(xdebug)
 
 	/* Reset compile, execute and error callbacks */
 	zend_compile_file = old_compile_file;
+#if PHP_VERSION_ID < 50500
 	zend_execute = xdebug_old_execute;
+#else
+	zend_execute_ex = xdebug_old_execute_ex;
+#endif
 	zend_execute_internal = xdebug_old_execute_internal;
 	zend_error_cb = xdebug_old_error_cb;
 
@@ -1212,10 +1233,17 @@ static int handle_breakpoints(function_stack_entry *fse, int breakpoint_type)
 	return 1;
 }
 
+#if PHP_VERSION_ID < 50500
 void xdebug_execute(zend_op_array *op_array TSRMLS_DC)
 {
-	zval                **dummy;
 	zend_execute_data    *edata = EG(current_execute_data);
+#else
+void xdebug_execute_ex(zend_execute_data *execute_data TSRMLS_DC)
+{
+	zend_op_array        *op_array = execute_data->op_array;
+	zend_execute_data    *edata = execute_data->prev_execute_data;
+#endif
+	zval                **dummy;
 	function_stack_entry *fse, *xfse;
 	char                 *magic_cookie = NULL;
 	int                   do_return = (XG(do_trace) && XG(trace_file));
@@ -1226,14 +1254,22 @@ void xdebug_execute(zend_op_array *op_array TSRMLS_DC)
 
 	/* If we're evaluating for the debugger's eval capability, just bail out */
 	if (op_array && op_array->filename && strcmp("xdebug://debug-eval", op_array->filename) == 0) {
+#if PHP_VERSION_ID < 50500
 		xdebug_old_execute(op_array TSRMLS_CC);
+#else
+		xdebug_old_execute_ex(execute_data TSRMLS_CC);
+#endif
 		return;
 	}
 
 	/* if we're in a ZEND_EXT_STMT, we ignore this function call as it's likely
 	   that it's just being called to check for breakpoints with conditions */
 	if (edata && edata->opline && edata->opline->opcode == ZEND_EXT_STMT) {
+#if PHP_VERSION_ID < 50500
 		xdebug_old_execute(op_array TSRMLS_CC);
+#else
+		xdebug_old_execute_ex(execute_data TSRMLS_CC);
+#endif
 		return;
 	}
 
@@ -1334,6 +1370,8 @@ void xdebug_execute(zend_op_array *op_array TSRMLS_DC)
 	}
 
 	fse = xdebug_add_stack_frame(edata, op_array, XDEBUG_EXTERNAL TSRMLS_CC);
+	fse->function.internal = 0;
+
 	/* A hack to make __call work with profiles. The function *is* user defined after all. */
 	if (fse && fse->prev && fse->function.function && (strcmp(fse->function.function, "__call") == 0)) {
 		fse->prev->user_defined = XDEBUG_EXTERNAL;
@@ -1343,7 +1381,11 @@ void xdebug_execute(zend_op_array *op_array TSRMLS_DC)
 	xdebug_trace_function_begin(fse, function_nr TSRMLS_CC);
 
 	fse->symbol_table = EG(active_symbol_table);
+#if PHP_VERSION_ID < 50500
 	fse->execute_data = EG(current_execute_data);
+#else
+	fse->execute_data = EG(current_execute_data)->prev_execute_data;
+#endif
 	fse->This = EG(This);
 
 	if (XG(remote_enabled) || XG(collect_vars) || XG(show_local_vars)) {
@@ -1388,7 +1430,12 @@ void xdebug_execute(zend_op_array *op_array TSRMLS_DC)
 		EG(return_value_ptr_ptr) = &return_val;
 		clear = 1;
 	}
+
+#if PHP_VERSION_ID < 50500
 	xdebug_old_execute(op_array TSRMLS_CC);
+#else
+	xdebug_old_execute_ex(execute_data TSRMLS_CC);
+#endif
 
 	if (XG(profiler_enabled)) {
 		xdebug_profiler_function_user_end(fse, op_array TSRMLS_CC);
@@ -1399,7 +1446,16 @@ void xdebug_execute(zend_op_array *op_array TSRMLS_DC)
 	/* Store return value in the trace file */
 	if (XG(collect_return) && do_return && XG(do_trace) && XG(trace_file)) {
 		if (EG(return_value_ptr_ptr) && *EG(return_value_ptr_ptr)) {
-			char* t = xdebug_return_trace_stack_retval(fse, *EG(return_value_ptr_ptr) TSRMLS_CC);
+			char *t;
+#if PHP_VERSION_ID >= 50500
+			if (op_array->fn_flags & ZEND_ACC_GENERATOR) {
+				t = xdebug_return_trace_stack_generator_retval(fse, (zend_generator *) EG(return_value_ptr_ptr) TSRMLS_CC);
+			} else {
+				t = xdebug_return_trace_stack_retval(fse, *EG(return_value_ptr_ptr) TSRMLS_CC);
+			}
+#else
+			t = xdebug_return_trace_stack_retval(fse, *EG(return_value_ptr_ptr) TSRMLS_CC);
+#endif
 			fprintf(XG(trace_file), "%s", t);
 			fflush(XG(trace_file));
 			xdfree(t);
@@ -1419,7 +1475,9 @@ void xdebug_execute(zend_op_array *op_array TSRMLS_DC)
 
 	fse->symbol_table = NULL;
 	fse->execute_data = NULL;
-	xdebug_llist_remove(XG(stack), XDEBUG_LLIST_TAIL(XG(stack)), xdebug_stack_element_dtor);
+	if (XG(stack)) {
+		xdebug_llist_remove(XG(stack), XDEBUG_LLIST_TAIL(XG(stack)), xdebug_stack_element_dtor);
+	}
 	XG(level)--;
 }
 
@@ -1439,7 +1497,11 @@ static int check_soap_call(function_stack_entry *fse)
 	return 0;
 }
 
+#if PHP_VERSION_ID < 50500
 void xdebug_execute_internal(zend_execute_data *current_execute_data, int return_value_used TSRMLS_DC)
+#else
+void xdebug_execute_internal(zend_execute_data *current_execute_data, struct _zend_fcall_info *fci, int return_value_used TSRMLS_DC)
+#endif
 {
 	zend_execute_data    *edata = EG(current_execute_data);
 	function_stack_entry *fse;
@@ -1456,6 +1518,7 @@ void xdebug_execute_internal(zend_execute_data *current_execute_data, int return
 	}
 
 	fse = xdebug_add_stack_frame(edata, edata->op_array, XDEBUG_INTERNAL TSRMLS_CC);
+	fse->function.internal = 1;
 
 	function_nr = XG(function_count);
 	xdebug_trace_function_begin(fse, function_nr TSRMLS_CC);
@@ -1477,11 +1540,19 @@ void xdebug_execute_internal(zend_execute_data *current_execute_data, int return
 	if (XG(profiler_enabled)) {
 		xdebug_profiler_function_internal_begin(fse TSRMLS_CC);
 	}
+#if PHP_VERSION_ID < 50500
 	if (xdebug_old_execute_internal) {
 		xdebug_old_execute_internal(current_execute_data, return_value_used TSRMLS_CC);
 	} else {
 		execute_internal(current_execute_data, return_value_used TSRMLS_CC);
 	}
+#else
+	if (xdebug_old_execute_internal) {
+		xdebug_old_execute_internal(current_execute_data, fci, return_value_used TSRMLS_CC);
+	} else {
+		execute_internal(current_execute_data, fci, return_value_used TSRMLS_CC);
+	}
+#endif
 
 	if (XG(profiler_enabled)) {
 		xdebug_profiler_function_internal_end(fse TSRMLS_CC);
@@ -1495,10 +1566,10 @@ void xdebug_execute_internal(zend_execute_data *current_execute_data, int return
 	xdebug_trace_function_end(fse, function_nr TSRMLS_CC);
 
 	/* Store return value in the trace file */
-	if (XG(collect_return) && do_return && XG(do_trace) && XG(trace_file)) {
+	if (XG(collect_return) && do_return && XG(do_trace) && XG(trace_file) && EG(opline_ptr)) {
 		cur_opcode = *EG(opline_ptr);
 		if (cur_opcode) {
-			zval *ret = xdebug_zval_ptr(cur_opcode->XDEBUG_TYPE(result), &(cur_opcode->result), current_execute_data->Ts TSRMLS_CC);
+			zval *ret = xdebug_zval_ptr(cur_opcode->XDEBUG_TYPE(result), &(cur_opcode->result), current_execute_data TSRMLS_CC);
 			if (ret) {
 				char* t = xdebug_return_trace_stack_retval(fse, ret TSRMLS_CC);
 				fprintf(XG(trace_file), "%s", t);
@@ -1546,20 +1617,53 @@ zend_op_array *xdebug_compile_file(zend_file_handle *file_handle, int type TSRML
 }
 /* }}} */
 
+#if PHP_VERSION_ID >= 50300
+static void xdebug_header_remove_with_prefix(xdebug_llist *headers, char *prefix, int prefix_len TSRMLS_DC)
+{
+	xdebug_llist_element *le;
+	char                 *header;
+
+	for (le = XDEBUG_LLIST_HEAD(XG(headers)); le != NULL; /* intentionally left blank*/) {
+		header = XDEBUG_LLIST_VALP(le);
+
+		if ((strlen(header) > prefix_len + 1) && (header[prefix_len] == ':') && (strncasecmp(header, prefix, prefix_len) == 0)) {
+			xdebug_llist_element *current = le;
+
+			le = XDEBUG_LLIST_NEXT(le);
+			xdebug_llist_remove(headers, current, NULL);
+		} else {
+			le = XDEBUG_LLIST_NEXT(le);
+		}
+	}
+}
+#endif
+
 static int xdebug_header_handler(sapi_header_struct *h XG_SAPI_HEADER_OP_DC, sapi_headers_struct *s TSRMLS_DC)
 {
 	if (XG(headers)) {
 #if PHP_VERSION_ID >= 50300
 		switch (op) {
 			case SAPI_HEADER_ADD:
-			case SAPI_HEADER_REPLACE:
 				xdebug_llist_insert_next(XG(headers), XDEBUG_LLIST_TAIL(XG(headers)), xdstrdup(h->header));
-			break;
+				break;
+			case SAPI_HEADER_REPLACE: {
+				char *colon_offset = strchr(h->header, ':');
+
+				if (colon_offset) {
+					char save = *colon_offset;
+
+					*colon_offset = '\0';
+					xdebug_header_remove_with_prefix(XG(headers), h->header, strlen(h->header) TSRMLS_CC);
+					*colon_offset = save;
+				}
+
+				xdebug_llist_insert_next(XG(headers), XDEBUG_LLIST_TAIL(XG(headers)), xdstrdup(h->header));
+			} break;
 			case SAPI_HEADER_DELETE_ALL:
 				xdebug_llist_empty(XG(headers), NULL);
 			case SAPI_HEADER_DELETE:
 			case SAPI_HEADER_SET_STATUS:
-			break;
+				break;
 		}
 #else
 		xdebug_llist_insert_next(XG(headers), XDEBUG_LLIST_TAIL(XG(headers)), xdstrdup(h->header));
@@ -1789,7 +1893,6 @@ PHP_FUNCTION(xdebug_get_headers)
 		string = XDEBUG_LLIST_VALP(le);
 		add_next_index_string(return_value, string, 1);
 	}
-	xdebug_llist_empty(XG(headers), NULL);
 }
 
 
@@ -1936,9 +2039,9 @@ ZEND_DLEXPORT void xdebug_statement_call(zend_op_array *op_array)
 						brk->disabled, lineno, brk->lineno, brk->file, file, file_len, brk->file_len);
 #endif
 #if PHP_WIN32
-				if (!brk->disabled && lineno == brk->lineno && strncasecmp(brk->file, file + file_len - brk->file_len, brk->file_len) == 0) {
+				if (!brk->disabled && lineno == brk->lineno && file_len >= brk->file_len && strncasecmp(brk->file, file + file_len - brk->file_len, brk->file_len) == 0) {
 #else
-				if (!brk->disabled && lineno == brk->lineno && memcmp(brk->file, file + file_len - brk->file_len, brk->file_len) == 0) {
+				if (!brk->disabled && lineno == brk->lineno && file_len >= brk->file_len && memcmp(brk->file, file + file_len - brk->file_len, brk->file_len) == 0) {
 #endif
 					break_ok = 1; /* Breaking is allowed by default */
 
