@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Xdebug                                                               |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2002-2012 Derick Rethans                               |
+   | Copyright (c) 2002-2013 Derick Rethans                               |
    +----------------------------------------------------------------------+
    | This source file is subject to version 1.0 of the Xdebug license,    |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -394,15 +394,20 @@ static zval* fetch_zval_from_symbol_table(HashTable *ht, char* name, int name_le
 				int i = 0;
 				ulong hash_value = zend_inline_hash_func(element, element_length + 1);
 				zend_op_array *opa = XG(active_op_array);
-				zval ***CVs = XG(active_execute_data)->CVs;
+				zval **CV;
 
 				while (i < opa->last_var) {
 					if (opa->vars[i].hash_value == hash_value &&
 						opa->vars[i].name_len == element_length &&
 						strcmp(opa->vars[i].name, element) == 0)
 					{
-						if (CVs[i]) {
-							retval_p = *CVs[i];
+#if PHP_VERSION_ID >= 50500
+						CV = (*EX_CV_NUM(XG(active_execute_data), i));
+#else
+						CV = XG(active_execute_data)->CVs[i];
+#endif
+						if (CV) {
+							retval_p = *CV;
 							goto cleanup;
 						}
 					}
@@ -779,9 +784,6 @@ static char* return_eval_source(char *id, int begin, int end TSRMLS_DC)
 static char* return_source(char *filename, int begin, int end TSRMLS_DC)
 {
 	if (strncmp(filename, "dbgp://", 7) == 0) {
-		if (strncmp(filename, "dbgp://phar://", 14) == 0) {
-			return return_file_source(filename + 7, begin, end TSRMLS_CC);
-		}
 		return return_eval_source(filename + 7, begin, end TSRMLS_CC);
 	} else {
 		return return_file_source(filename, begin, end TSRMLS_CC);
