@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Xdebug                                                               |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2002-2012 Derick Rethans                               |
+   | Copyright (c) 2002-2013 Derick Rethans                               |
    +----------------------------------------------------------------------+
    | This source file is subject to version 1.0 of the Xdebug license,    |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -27,6 +27,10 @@
 #include "zend_constants.h"
 #include "zend_extensions.h"
 #include "zend_exceptions.h"
+#if PHP_VERSION_ID >= 50500
+#include "zend_generators.h"
+#endif
+#include "zend_exceptions.h"
 #include "zend_vm.h"
 #include "zend_hash.h"
 #include "xdebug_hash.h"
@@ -50,7 +54,6 @@ typedef struct xdebug_var {
 #define XFUNC_NORMAL         0x01
 #define XFUNC_STATIC_MEMBER  0x02
 #define XFUNC_MEMBER         0x03
-#define XFUNC_NEW            0x04
 
 #define XFUNC_INCLUDES       0x10
 #define XFUNC_EVAL           0x10
