@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Xdebug                                                               |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2002-2012 Derick Rethans                               |
+   | Copyright (c) 2002-2013 Derick Rethans                               |
    +----------------------------------------------------------------------+
    | This source file is subject to version 1.0 of the Xdebug license,    |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -478,7 +478,7 @@ void xdebug_init_debugger(TSRMLS_D)
 	if (XG(remote_connect_back)) {
 		zval **remote_addr = NULL;
 		XDEBUG_LOG_PRINT(XG(remote_log_file), "I: Checking remote connect back address.\n");
-		if (zend_hash_find(Z_ARRVAL_P(PG(http_globals)[TRACK_VARS_SERVER]), "X_HTTP_FORWARDED_FOR", 21, (void**)&remote_addr) == FAILURE) {
+		if (zend_hash_find(Z_ARRVAL_P(PG(http_globals)[TRACK_VARS_SERVER]), "HTTP_X_FORWARDED_FOR", 21, (void**)&remote_addr) == FAILURE) {
 			zend_hash_find(Z_ARRVAL_P(PG(http_globals)[TRACK_VARS_SERVER]), "REMOTE_ADDR", 12, (void**)&remote_addr);
 		}
 		if (remote_addr) {
@@ -622,8 +622,12 @@ void xdebug_error_cb(int type, const char *error_filename, const uint error_line
 				
 				/* find first new line */
 				p = strchr(buffer, '\n');
-				/* find last quote */
-				p = ((char *) zend_memrchr(buffer, '\'', p - buffer)) + 1;
+				if (!p) {
+					p = buffer + strlen(buffer);
+				} else {
+					/* find last quote */
+					p = ((char *) zend_memrchr(buffer, '\'', p - buffer)) + 1;
+				}
 				/* Create new buffer */
 				tmp_buf = calloc(p - buffer + 1, 1);
 				strncpy(tmp_buf, buffer, p - buffer );
@@ -632,7 +636,9 @@ void xdebug_error_cb(int type, const char *error_filename, const uint error_line
 				xdebug_append_error_head(&str, PG(html_errors), "uncaught-exception" TSRMLS_CC);
 				xdebug_append_error_description(&str, PG(html_errors), error_type_str, tmp_buf, error_filename, error_lineno TSRMLS_CC);
 				xdebug_append_printable_stack(&str, PG(html_errors) TSRMLS_CC);
-				xdebug_str_add(&str, XG(last_exception_trace), 0);
+				if (XG(last_exception_trace)) {
+					xdebug_str_add(&str, XG(last_exception_trace), 0);
+				}
 				xdebug_append_error_footer(&str, PG(html_errors) TSRMLS_CC);
 				php_output_error(str.d TSRMLS_CC);
 
@@ -922,7 +928,8 @@ static void xdebug_build_fname(xdebug_func *tmp, zend_execute_data *edata TSRMLS
 
 function_stack_entry *xdebug_add_stack_frame(zend_execute_data *zdata, zend_op_array *op_array, int type TSRMLS_DC)
 {
-	zend_execute_data    *edata = EG(current_execute_data);
+	zend_execute_data    *edata;
+	zend_op             **opline_ptr = NULL;
 	function_stack_entry *tmp;
 	zend_op              *cur_opcode;
 	zval                **param;
@@ -930,6 +937,21 @@ function_stack_entry *xdebug_add_stack_frame(zend_execute_data *zdata, zend_op_a
 	char                 *aggr_key = NULL;
 	int                   aggr_key_len = 0;
 
+#if PHP_VERSION_ID < 50500
+	edata = EG(current_execute_data);
+	opline_ptr = EG(opline_ptr);
+#else
+	if (type == XDEBUG_EXTERNAL) {
+		edata = EG(current_execute_data)->prev_execute_data;
+		if (edata) {
+			opline_ptr = &edata->opline;
+		}
+	} else {
+		edata = EG(current_execute_data);
+		opline_ptr = EG(opline_ptr);
+	}
+#endif
+
 	tmp = xdmalloc (sizeof (function_stack_entry));
 	tmp->var           = NULL;
 	tmp->varc          = 0;
@@ -949,7 +971,11 @@ function_stack_entry *xdebug_add_stack_frame(zend_execute_data *zdata, zend_op_a
 	if (edata && edata->op_array) {
 		/* Normal function calls */
 		tmp->filename  = xdstrdup(edata->op_array->filename);
-	} else if (edata && edata->prev_execute_data && XDEBUG_LLIST_TAIL(XG(stack))
+	} else if (
+		edata &&
+		edata->prev_execute_data &&
+		XDEBUG_LLIST_TAIL(XG(stack)) &&
+		((function_stack_entry*) XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack))))->filename
 	) {
 		tmp->filename = xdstrdup(((function_stack_entry*) XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack))))->filename);
 	}
@@ -959,9 +985,18 @@ function_stack_entry *xdebug_add_stack_frame(zend_execute_data *zdata, zend_op_a
 		tmp->filename  = (op_array && op_array->filename) ? xdstrdup(op_array->filename): NULL;
 	}
 	/* Call user function locations */
-	if (!tmp->filename && XDEBUG_LLIST_TAIL(XG(stack)) && XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack))) ) {
+	if (
+		!tmp->filename &&
+		XDEBUG_LLIST_TAIL(XG(stack)) &&
+		XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack))) &&
+		((function_stack_entry*) XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack))))->filename
+	) {
 		tmp->filename = xdstrdup(((function_stack_entry*) XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack))))->filename);
 	}
+
+	if (!tmp->filename) {
+		tmp->filename = xdstrdup("UNKNOWN?");
+	}
 #if HAVE_PHP_MEMORY_USAGE
 	tmp->prev_memory = XG(prev_memory);
 	tmp->memory = XG_MEMORY_USAGE();
@@ -972,6 +1007,7 @@ function_stack_entry *xdebug_add_stack_frame(zend_execute_data *zdata, zend_op_a
 #endif
 	tmp->time   = xdebug_get_utime();
 	tmp->lineno = 0;
+	tmp->prev   = 0;
 
 	xdebug_build_fname(&(tmp->function), zdata TSRMLS_CC);
 	if (!tmp->function.type) {
@@ -980,8 +1016,8 @@ function_stack_entry *xdebug_add_stack_frame(zend_execute_data *zdata, zend_op_a
 		tmp->function.type     = XFUNC_NORMAL;
 
 	} else if (tmp->function.type & XFUNC_INCLUDES) {
-		if (EG(opline_ptr)) {
-			cur_opcode = *EG(opline_ptr);
+		if (opline_ptr) {
+			cur_opcode = *opline_ptr;
 			tmp->lineno = cur_opcode->lineno;
 		} else {
 			tmp->lineno = 0;
@@ -1120,24 +1156,24 @@ function_stack_entry *xdebug_add_stack_frame(zend_execute_data *zdata, zend_op_a
 		}
 	}
 
-	if (XDEBUG_LLIST_TAIL(XG(stack))) {
-		function_stack_entry *prev = XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack)));
-		tmp->prev = prev;
-		if (XG(profiler_aggregate)) {
-			if (prev->aggr_entry->call_list) {
-				if (!zend_hash_exists(prev->aggr_entry->call_list, aggr_key, aggr_key_len+1)) {
+	if (XG(stack)) {
+		if (XDEBUG_LLIST_TAIL(XG(stack))) {
+			function_stack_entry *prev = XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack)));
+			tmp->prev = prev;
+			if (XG(profiler_aggregate)) {
+				if (prev->aggr_entry->call_list) {
+					if (!zend_hash_exists(prev->aggr_entry->call_list, aggr_key, aggr_key_len+1)) {
+						zend_hash_add(prev->aggr_entry->call_list, aggr_key, aggr_key_len+1, (void*)&tmp->aggr_entry, sizeof(xdebug_aggregate_entry*), NULL);
+					}
+				} else {
+					prev->aggr_entry->call_list = xdmalloc(sizeof(HashTable));
+					zend_hash_init_ex(prev->aggr_entry->call_list, 1, NULL, NULL, 1, 0);
 					zend_hash_add(prev->aggr_entry->call_list, aggr_key, aggr_key_len+1, (void*)&tmp->aggr_entry, sizeof(xdebug_aggregate_entry*), NULL);
 				}
-			} else {
-				prev->aggr_entry->call_list = xdmalloc(sizeof(HashTable));
-				zend_hash_init_ex(prev->aggr_entry->call_list, 1, NULL, NULL, 1, 0);
-				zend_hash_add(prev->aggr_entry->call_list, aggr_key, aggr_key_len+1, (void*)&tmp->aggr_entry, sizeof(xdebug_aggregate_entry*), NULL);
 			}
 		}
-	} else {
-		tmp->prev = 0;
+		xdebug_llist_insert_next(XG(stack), XDEBUG_LLIST_TAIL(XG(stack)), tmp);
 	}
-	xdebug_llist_insert_next(XG(stack), XDEBUG_LLIST_TAIL(XG(stack)), tmp);
 
 	if (XG(profiler_aggregate)) {
 		xdfree(aggr_key);
