@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Xdebug                                                               |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2002-2012 Derick Rethans                               |
+   | Copyright (c) 2002-2013 Derick Rethans                               |
    +----------------------------------------------------------------------+
    | This source file is subject to version 1.0 of the Xdebug license,    |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -122,9 +122,13 @@ char* xdebug_error_type(int type)
 }
 
 /*************************************************************************************************************************************/
-#define T(offset) (*(temp_variable *)((char *) Ts + offset))
+#if PHP_VERSION_ID >= 50500
+# define T(offset) (*EX_TMP_VAR(zdata, offset))
+#else
+# define T(offset) (*(temp_variable *)((char*)zdata->Ts + offset))
+#endif
 
-zval *xdebug_get_zval(zend_execute_data *zdata, int node_type, XDEBUG_ZNODE *node, temp_variable *Ts, int *is_var)
+zval *xdebug_get_zval(zend_execute_data *zdata, int node_type, XDEBUG_ZNODE *node, int *is_var)
 {
 	switch (node_type) {
 		case IS_CONST:
@@ -392,7 +396,7 @@ void xdebug_var_export(zval **struc, xdebug_str *str, int level, int debug_zval,
 			break;
 
 		case IS_STRING:
-			tmp_str = php_addcslashes(Z_STRVAL_PP(struc), Z_STRLEN_PP(struc), &tmp_len, 0, "'\\\0..\37", 6 TSRMLS_CC);
+			tmp_str = php_addcslashes(Z_STRVAL_PP(struc), Z_STRLEN_PP(struc), &tmp_len, 0, "'\\\0..\37", 7 TSRMLS_CC);
 			if (options->no_decoration) {
 				xdebug_str_add(str, tmp_str, 0);
 			} else if (Z_STRLEN_PP(struc) <= options->max_data) {
@@ -676,6 +680,9 @@ void xdebug_var_export_text_ansi(zval **struc, xdebug_str *str, int mode, int le
 	HashTable *myht;
 	char*     tmp_str;
 	int       tmp_len;
+#if PHP_VERSION_ID >= 50300
+	int       is_temp;
+#endif
 
 	if (!struc || !(*struc)) {
 		return;
@@ -704,9 +711,13 @@ void xdebug_var_export_text_ansi(zval **struc, xdebug_str *str, int mode, int le
 			break;
 
 		case IS_STRING:
-			tmp_str = php_addcslashes(Z_STRVAL_PP(struc), Z_STRLEN_PP(struc), &tmp_len, 0, "\0..\37", 5 TSRMLS_CC);
+			if (mode == 1) {
+				tmp_str = php_addcslashes(Z_STRVAL_PP(struc), Z_STRLEN_PP(struc), &tmp_len, 0, "'\\\0..\37", 7 TSRMLS_CC);
+			} else {
+				tmp_str = php_addcslashes(Z_STRVAL_PP(struc), Z_STRLEN_PP(struc), &tmp_len, 0, "\0", 1 TSRMLS_CC);
+			}
 			if (options->no_decoration) {
-				xdebug_str_add(str, tmp_str, 0);
+				xdebug_str_addl(str, tmp_str, tmp_len, 0);
 			} else if (Z_STRLEN_PP(struc) <= options->max_data) {
 				xdebug_str_add(str, xdebug_sprintf("%sstring%s(%s%ld%s) \"%s%s%s\"", ANSI_COLOR_BOLD, ANSI_COLOR_BOLD_OFF, 
 							ANSI_COLOR_LONG, Z_STRLEN_PP(struc), ANSI_COLOR_RESET,
@@ -740,8 +751,12 @@ void xdebug_var_export_text_ansi(zval **struc, xdebug_str *str, int mode, int le
 			break;
 
 		case IS_OBJECT:
+#if PHP_VERSION_ID >= 50300
+			myht = Z_OBJDEBUG_PP(struc, is_temp);
+#else
 			myht = Z_OBJPROP_PP(struc);
-			if (myht->nApplyCount < 1) {
+#endif
+			if (myht && myht->nApplyCount < 1) {
 				char *class_name;
 				zend_uint class_name_len;
 
@@ -764,6 +779,12 @@ void xdebug_var_export_text_ansi(zval **struc, xdebug_str *str, int mode, int le
 			} else {
 				xdebug_str_add(str, xdebug_sprintf("%*s...\n", (level * 2), ""), 1);
 			}
+#if PHP_VERSION_ID >= 50300
+			if (is_temp) {
+				zend_hash_destroy(myht);
+				efree(myht);
+			}
+#endif
 			break;
 
 		case IS_RESOURCE: {
@@ -931,7 +952,15 @@ static int object_item_add_zend_prop_to_merged_hash(zend_property_info *zpp XDEB
 
 	item = xdmalloc(sizeof(xdebug_object_item));
 	item->type = object_type;
+#if ZTS
+	if (ce->type == 1) {
+		item->zv   = CG(static_members_table)[(zend_intptr_t) ce->static_members_table][zpp->offset];
+	} else {
+		item->zv   = ce->static_members_table[zpp->offset];
+	}
+#else
 	item->zv   = ce->static_members_table[zpp->offset];
+#endif
 	item->name = (char *) zpp->name;
 	item->name_len = zpp->name_length;
 
@@ -1252,7 +1281,7 @@ void xdebug_var_export_xml_node(zval **struc, char *name, xdebug_xml_node *node,
 
 #if PHP_VERSION_ID >= 50400
 			/* Adding static properties */
-			if (ce->static_members_table) {
+			if (&ce->properties_info) {
 				zend_hash_apply_with_arguments(&ce->properties_info XDEBUG_ZEND_HASH_APPLY_TSRMLS_CC, (apply_func_args_t) object_item_add_zend_prop_to_merged_hash, 3, merged_hash, (int) XDEBUG_OBJECT_ITEM_TYPE_STATIC_PROPERTY, ce);
 			}
 
@@ -1678,6 +1707,39 @@ char* xdebug_xmlize(char *string, int len, int *newlen)
 /*****************************************************************************
 ** Function name printing function
 */
+static char* xdebug_create_doc_link(xdebug_func f TSRMLS_DC)
+{
+	char *tmp_target, *p, *retval;
+
+	switch (f.type) {
+		case XFUNC_NORMAL: {
+			tmp_target = xdebug_sprintf("function.%s", f.function);
+			break;
+		}
+
+		case XFUNC_STATIC_MEMBER:
+		case XFUNC_MEMBER: {
+			if (strcmp(f.function, "__construct") == 0) {
+				tmp_target = xdebug_sprintf("%s.construct", f.class);
+			} else {
+				tmp_target = xdebug_sprintf("%s.%s", f.class, f.function);
+			}
+			break;
+		}
+	}
+
+	while ((p = strchr(tmp_target, '_')) != NULL) {
+		*p = '-';
+	}
+
+	retval = xdebug_sprintf("<a href='%s%s%s' target='_new'>%s</a>\n",
+		(PG(docref_root) && PG(docref_root)[0]) ? PG(docref_root) : "http://www.php.net/",
+		tmp_target, PG(docref_ext), f.function);
+
+	xdfree(tmp_target);
+
+	return retval;
+}
 
 char* xdebug_show_fname(xdebug_func f, int html, int flags TSRMLS_DC)
 {
@@ -1685,57 +1747,27 @@ char* xdebug_show_fname(xdebug_func f, int html, int flags TSRMLS_DC)
 
 	switch (f.type) {
 		case XFUNC_NORMAL: {
-			zend_function *zfunc;
-
-			if (PG(html_errors) && EG(function_table) && zend_hash_find(EG(function_table), f.function, strlen(f.function) + 1, (void**) &zfunc) == SUCCESS) {
-				if (html && zfunc->type == ZEND_INTERNAL_FUNCTION) {
-					return xdebug_sprintf("<a href='%s/%s%s' target='_new'>%s</a>\n",
-						(PG(docref_root) && PG(docref_root)[0]) ? PG(docref_root) : "http://www.php.net",
-						f.function, PG(docref_ext), f.function);
-				} else {
-					return xdstrdup(f.function);
-				}
+			if (PG(html_errors) && html && f.internal) {
+				return xdebug_create_doc_link(f TSRMLS_CC);
 			} else {
 				return xdstrdup(f.function);
 			}
 			break;
 		}
 
-		case XFUNC_NEW:
-			if (!f.class) {
-				f.class = "?";
-			}
-			if (!f.function) {
-				f.function = "?";
-			}
-			tmp = xdmalloc(strlen(f.class) + 4 + 1);
-			sprintf(tmp, "new %s", f.class);
-			return tmp;
-			break;
-
 		case XFUNC_STATIC_MEMBER:
-			if (!f.class) {
-				f.class = "?";
+		case XFUNC_MEMBER: {
+			if (PG(html_errors) && html && f.internal) {
+				return xdebug_create_doc_link(f TSRMLS_CC);
+			} else {
+				return xdebug_sprintf("%s%s%s",
+					f.class ? f.class : "?",
+					f.type == XFUNC_STATIC_MEMBER ? "::" : "->",
+					f.function ? f.function : "?"
+				);
 			}
-			if (!f.function) {
-				f.function = "?";
-			}
-			tmp = xdmalloc(strlen(f.function) + strlen(f.class) + 2 + 1);
-			sprintf(tmp, "%s::%s", f.class, f.function);
-			return tmp;
-			break;
-
-		case XFUNC_MEMBER:
-			if (!f.class) {
-				f.class = "?";
-			}
-			if (!f.function) {
-				f.function = "?";
-			}
-			tmp = xdmalloc(strlen(f.function) + strlen(f.class) + 2 + 1);
-			sprintf(tmp, "%s->%s", f.class, f.function);
-			return tmp;
 			break;
+		}	
 
 		case XFUNC_EVAL:
 			return xdstrdup("eval");
